# qubisafe

A simple Python package to open Qubisafe's website.

## Installation

```bash
pip install qubisafe
```

## Usage

```python
from qubisafe import website

website()  # Opens https://qubisafe.github.io in your default browser
```

## License
MIT